/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="convert_document_request.dart">
 *   Copyright (c) 2022 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import 'dart:typed_data';
import '../../aspose_words_cloud.dart';
import '../api_client.dart';
import '../api_request_data.dart';
import '../api_request_part.dart';

/// Request model for ConvertDocument operation.
class ConvertDocumentRequest implements RequestBase {
  /// Converting document.
  final ByteData document;

  /// The format to convert.
  final String format;

  /// The path to the output document on a local storage.
  final String outPath;

  /// The filename of the output document, that will be used when the resulting document has a dynamic field {filename}. If it is not set, the "sourceFilename" will be used instead.
  final String fileNameFieldValue;

  /// Original document storage.
  final String storage;

  /// Folder in filestorage with custom fonts.
  final String fontsLocation;

  ConvertDocumentRequest(final this.document, final this.format,
      {final this.outPath,
      final this.fileNameFieldValue,
      final this.storage,
      final this.fontsLocation});

  @override
  Future<ApiRequestData> createRequestData(final ApiClient _apiClient) async {
    var _path = '/words/convert';
    var _queryParams = <String, String>{};
    var _headers = <String, String>{};
    var _bodyParts = <ApiRequestPart>[];
    if (format != null) {
      _queryParams['format'] = _apiClient.serializeToString(format);
    } else {
      throw ApiException(400, 'Parameter format is required.');
    }

    if (outPath != null) {
      _queryParams['outPath'] = _apiClient.serializeToString(outPath);
    }

    if (fileNameFieldValue != null) {
      _queryParams['fileNameFieldValue'] =
          _apiClient.serializeToString(fileNameFieldValue);
    }

    if (storage != null) {
      _queryParams['storage'] = _apiClient.serializeToString(storage);
    }

    if (fontsLocation != null) {
      _queryParams['fontsLocation'] =
          _apiClient.serializeToString(fontsLocation);
    }

    if (document != null) {
      _bodyParts.add(ApiRequestPart(
          _apiClient.serializeBody(document), 'application/octet-stream',
          name: 'Document'));
    } else {
      throw ApiException(400, 'Parameter document is required.');
    }

    var _url = _apiClient.configuration.getApiRootUrl() +
        _apiClient.applyQueryParams(_path, _queryParams).replaceAll('//', '/');
    var _body = _apiClient.serializeBodyParts(_bodyParts, _headers);
    return ApiRequestData('PUT', _url, _headers, _body);
  }

  @override
  dynamic deserializeResponse(
      final ApiClient _apiClient, final ByteData _body) {
    return _body;
  }
}
